<?php

namespace Buyesrfolio\Transaction\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Buyesrfolio\Transaction\Models\Transaction;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Buyesrfolio\Transaction\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/transaction/past_transaction/*')) {
            Route::bind('past_transaction', function ($past_transaction) {
                $past_transactionrepo = $this->app->make('Buyesrfolio\Transaction\Interfaces\PastTransactionRepositoryInterface');
                return $past_transactionrepo->findorNew($past_transaction);
            });
        }
        if (Request::is('*/transaction/transaction_file/*')) {
            Route::bind('transaction_file', function ($transaction_file) {
                $transaction_filerepo = $this->app->make('Buyesrfolio\Transaction\Interfaces\TransactionFileRepositoryInterface');
                return $transaction_filerepo->findorNew($transaction_file);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
