<?php

namespace Buyesrfolio\Transaction\Providers;

use Illuminate\Support\ServiceProvider;

class TransactionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'transaction');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'transaction');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTransaction();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTransaction()
    {
        $this->app->bind('transaction', function($app) {
            return new Transaction($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Transaction', 'Lavalite\Transaction\Facades\Transaction');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('buyesrfolio.transaction', function ($app) {
            return $this->app->make('Buyesrfolio\Transaction\Transaction');
        });

        // Bind PastTransaction to repository
        $this->app->bind(
            'Buyesrfolio\Transaction\Interfaces\PastTransactionRepositoryInterface',
            \Buyesrfolio\Transaction\Repositories\Eloquent\PastTransactionRepository::class
        );        // Bind TransactionFile to repository
        $this->app->bind(
            'Buyesrfolio\Transaction\Interfaces\TransactionFileRepositoryInterface',
            \Buyesrfolio\Transaction\Repositories\Eloquent\TransactionFileRepository::class
        );

        $this->app->register(\Buyesrfolio\Transaction\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Buyesrfolio\Transaction\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and transaction's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'buyesrfolio.transaction'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTransaction::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['buyesrfolio.transaction'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('buyesrfolio/transaction.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/transaction')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/transaction')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
